# LaVue - Parameters Tool

Created by Jan Kotanski, last modified on kwi 02, 2020 10:41

Parameters Tool allows to read and write tango attributes to change detector settings

- Setup: add and remove tango device attributes and their labels to the list of parameters
- Apply: write parameter values from the white edit widget to the corresponding tango device attribute

Read values of parameters are displayed in the corresponding green widgets.